from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text(encoding="utf-8")

setup(
    name="goodgute",  
    author="Paddy",
    version="1.0.2",
    long_description=long_description,                    # README内容
    long_description_content_type="text/markdown", 
    packages=find_packages(),
        install_requires=[
       # "fastapi==0.115.0",
       # "uvicorn==0.30.0",
        "pydantic==2.8.2",
        "nltk==3.9.1",
        "requests",
        "colorama",
        "python-docx",
        "PyMuPDF",
    ],
    entry_points={
        "console_scripts": [
            "GoodGute=goodgute.cli:main",
        ],
    },
)
